==> myfaces-tobago-6.3.0-source-release.zip: tobago-6.3.0/tobago-tool/tobago-tool-annotation/src/main/java/org/apache/myfaces/tobago/apt/annotation/UIComponentTag.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.apt.annotation;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.lang.annotation.ElementType;

@Retention(value = RetentionPolicy.SOURCE)
@Target(value = ElementType.TYPE)

public @interface UIComponentTag {

  String uiComponent();

  /**
   * @deprecated since 4.4.0. Will set automatically.
   */
  @Deprecated
  String uiComponentBaseClass() default "";

  String uiComponentFacesClass() default "jakarta.faces.component.UIComponentBase";

  /**
   * @deprecated since 4.4.0. Will set automatically.
   */
  @Deprecated
  String componentType() default "";

  String componentFamily() default "";

  String[] rendererType() default {};

  String faceletHandler() default "org.apache.myfaces.tobago.facelets.TobagoComponentHandler";

  String displayName() default "";

  String[] interfaces() default {};

  Facet[] facets() default {};

  Behavior[] behaviors() default {};

  Markup[] markups() default {};

  boolean generate() default true;

  boolean isComponentAlreadyDefined() default false;

  /**
   * Array of supported component-types that explicitly enumerates the
   * set of allowed component children for this component. Other possible values are: ALL...
   */
  String[] allowedChildComponenents() default {"ALL"};

  /**
   * Specifies the category of a component palette.
   */
  Category category() default Category.GENERAL;

  /**
   * Specifies whether this component should be available on a component palette.
   */
  boolean isHidden() default false;


}

==> myfaces-tobago-6.9.1-source-release.zip: tobago-6.9.1/tobago-tool/tobago-tool-annotation/src/main/java/org/apache/myfaces/tobago/apt/annotation/UIComponentTag.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.apt.annotation;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.lang.annotation.ElementType;

@Retention(value = RetentionPolicy.SOURCE)
@Target(value = ElementType.TYPE)

public @interface UIComponentTag {

  String uiComponent();

  /**
   * @deprecated Will set automatically.
   */
  @Deprecated(since = "4.4.0", forRemoval = true)
  String uiComponentBaseClass() default "";

  String uiComponentFacesClass() default "jakarta.faces.component.UIComponentBase";

  /**
   * @deprecated Will set automatically.
   */
  @Deprecated(since = "4.4.0", forRemoval = true)
  String componentType() default "";

  String componentFamily() default "";

  String[] rendererType() default {};

  String faceletHandler() default "org.apache.myfaces.tobago.facelets.TobagoComponentHandler";

  String displayName() default "";

  String[] interfaces() default {};

  Facet[] facets() default {};

  Behavior[] behaviors() default {};

  Markup[] markups() default {};

  boolean generate() default true;

  boolean isComponentAlreadyDefined() default false;

  /**
   * Array of supported component-types that explicitly enumerates the
   * set of allowed component children for this component. Other possible values are: ALL...
   */
  String[] allowedChildComponents() default {"ALL"};

  @Deprecated(since = "5.15.0", forRemoval = true)
  String[] allowedChildComponenents() default {};

  /**
   * Specifies the category of a component palette.
   */
  Category category() default Category.GENERAL;

  /**
   * Specifies whether this component should be available on a component palette.
   */
  boolean isHidden() default false;


}
